@@ -56,7 +56,7 @@ class HelpManager(object):
         self._workdir = None
         self.set_workdir(workdir)
 
-        self._setup_connect_tables()
+        self._load_connect_tables()
 
     @property
     def cellnames(self):
@@ -97,8 +97,8 @@ class HelpManager(object):
     def path_connect_tables(self):
         return osp.join(self.inputdir, FNAME_CONN_TABLES)
 
-    def _setup_connect_tables(self):
-        """Setup the connect tables dictionary."""
+    def _load_connect_tables(self):
+        """Load the connect tables from the json file."""
         if osp.exists(self.path_connect_tables):
             with open(self.path_connect_tables, 'r') as jsonfile:
                 self.connect_tables = json.load(jsonfile)
@@ -106,7 +106,7 @@ class HelpManager(object):
             self.connect_tables = {}
 
     def _save_connect_tables(self):
-        """Save the connect tables dictionary to a json text file."""
+        """Save the connect tables to a json text file."""
         with open(self.path_connect_tables, 'w', encoding='utf-8') as jsonfile:
             json.dump(self.connect_tables, jsonfile, indent=2,
                       separators=(",", ": "), ensure_ascii=False)
@@ -374,8 +374,7 @@ class HelpManager(object):
 
         output_data = run_help_allcells(cellparams)
         output_data = self._post_process_output(output_data)
-        output_grid = self.grid.loc[output_data['cid']]
-        help_output = HelpOutput({'data': output_data, 'grid': output_grid})
+        help_output = HelpOutput(output_data)
         if path_to_hdf5:
             help_output.save_to_hdf5(path_to_hdf5)
 
@@ -396,10 +395,12 @@ class HelpManager(object):
         Return a dict that contains a 3D numpy array with the monthly values
         for precip, runoff, evapo, perco, subrun1, subrun2, and rechg. The
         dict also contains lists for the cid (cell id) and years corresponding
-        to the i and j indexes of the 3D numpy arrays. A list with the
-        i indexes where data is nan is also saved in the dict. Nan values
-        are obtained when HELP is not able to do water budget calculations due
-        to lack of data or when there is an error in the input data.
+        to the i and j indexes of the 3D numpy arrays.
+
+        A list with the indexes of the cells where data is nan is also saved
+        in the dict. Nan values are obtained when HELP is not able to do water
+        budget calculations due to lack of data or when there is an error in
+        the input data.
         """
         cellnames = list(output.keys())
         context = self.grid['context'][cellnames].tolist()
@@ -413,6 +414,8 @@ class HelpManager(object):
         data['cid'] = cellnames
         data['years'] = years
         data['idx_nan'] = []
+        data['lat_dd'] = self.grid.loc[cellnames]['lat_dd'].values
+        data['lon_dd'] = self.grid.loc[cellnames]['lon_dd'].values
 
         for i, cellname in enumerate(cellnames):
             print("\rPost-processing cell %d of %d..." % (i+1, Np), end=' ')
@@ -531,16 +534,13 @@ def load_grid_from_csv(path_togrid):
     Load the csv that contains the infos required to evaluate regional
     groundwater recharge with HELP.
     """
-    grid = pd.read_csv(path_togrid)
+    grid = pd.read_csv(path_togrid, dtype={'cid': 'str'})
 
     fname = osp.basename(path_togrid)
-    req_keys = ['cid', 'lat_dd', 'lon_dd', 'run']
+    req_keys = ['cid', 'lat_dd', 'lon_dd', 'run', 'context']
     for key in req_keys:
         if key not in grid.keys():
-            raise KeyError("No attribute '%s' found in %s" % (key, fname))
-
-    # Make sure that cid is a str.
-    grid['cid'] = np.array(grid['cid']).astype(str)
+            raise KeyError("No attribute '{}' found in {}".format(key, fname))
 
     # Set 'cid' as the index of the dataframe.
     grid.set_index(['cid'], drop=False, inplace=True)
